This module contains methods for calculating the distance between two configurations as well as the distances between 
multiple configurations.  The functionality within this module is used in both the [mapping](module_mapping.md) and 
[dimred](module_dimred.md) modules.
